@@ -1,4 +1,4 @@
-# Copyright (c) 2018-2020 Micro Focus or one of its affiliates.
+# Copyright (c) 2018-2022 Micro Focus or one of its affiliates.
 # Copyright (c) 2018 Uber Technologies, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -74,3 +74,7 @@ class Describe(BulkFrontendMessage):
         utf_name = self._describe_name.encode('utf-8')
         bytes_ = pack('c{0}sx'.format(len(utf_name)), self._describe_type, utf_name)
         return bytes_
+
+    def __str__(self):
+        return 'Describe: type = {}, name = "{}"'.format(
+               'Portal' if self._describe_type == b'P' else 'Prepared Statement' , self._describe_name)
